summaryrefslogtreecommitdiff
path: root/lib/ZLocations.c
diff options
context:
space:
mode:
authorGravatar Robert S. French <rfrench@mit.edu>1987-10-31 11:03:13 +0000
committerGravatar Robert S. French <rfrench@mit.edu>1987-10-31 11:03:13 +0000
commit370b1634a1f95be3953cf96ae535af75e7df0a83 (patch)
treef1272cdd4e993bc6fbb96fb308e6253db6d1dec4 /lib/ZLocations.c
parent75fd78048b0659ab7d80a8ceb78f615c659c8013 (diff)
Deleted ZHideLocation and ZUnhideLocation
Diffstat (limited to 'lib/ZLocations.c')
-rw-r--r--lib/ZLocations.c33
1 files changed, 6 insertions, 27 deletions
diff --git a/lib/ZLocations.c b/lib/ZLocations.c
index 8773e57..7baf4d3 100644
--- a/lib/ZLocations.c
+++ b/lib/ZLocations.c
@@ -1,6 +1,6 @@
/* This file is part of the Project Athena Zephyr Notification System.
* It contains source for the ZSetLocation, ZUnsetLocation, ZHideLocation,
* and ZUnhideLocation functions.
*
* Created by: Robert French
*
@@ -28,21 +28,10 @@ static char rcsid_ZLocations_c[] = "$Header$";
uid_t getuid();
-Code_t ZSetLocation()
+Code_t ZSetLocation(exposure)
+ char *exposure;
{
- char bfr[BUFSIZ];
- int quiet;
- struct passwd *pw;
-
- quiet = 0;
- /* XXX a uid_t is a u_short (now), but getpwuid wants an int. AARGH! */
- if (pw = getpwuid((int) getuid())) {
- (void) sprintf(bfr,"%s/.hideme",pw->pw_dir);
- quiet = !access(bfr,F_OK);
- }
-
- return (Z_SendLocation(LOGIN_CLASS,quiet?LOGIN_QUIET_LOGIN:
- LOGIN_USER_LOGIN,ZAUTH,
+ return (Z_SendLocation(LOGIN_CLASS,exposure,ZAUTH,
"$sender logged in to $1 on $3 at $2"));
}
@@ -52,21 +41,11 @@ Code_t ZUnsetLocation()
"$sender logged out of $1 on $3 at $2"));
}
-Code_t ZFlushLocations()
+Code_t ZFlushMyLocations()
{
return (Z_SendLocation(LOGIN_CLASS,LOGIN_USER_FLUSH,ZAUTH,""));
}
-Code_t ZHideLocation()
-{
- return (Z_SendLocation(LOCATE_CLASS,LOCATE_HIDE,ZAUTH,(char *)0));
-}
-
-Code_t ZUnhideLocation()
-{
- return (Z_SendLocation(LOCATE_CLASS,LOCATE_UNHIDE,ZAUTH,(char *)0));
-}
-
Z_SendLocation(class,opcode,auth,format)
char *class;
char *opcode;
@@ -1,6 +1,6 @@
/* This file is part of the Project Athena Zephyr Notification System.
- * It contains source for the ZSetLocation, ZUnsetLocation, ZHideLocation,
- * and ZUnhideLocation functions.
+ * It contains source for the ZSetLocation, ZUnsetLocation, and
+ * ZFlushMyLocations functions.
*
* Created by: Robert French